//
//  TestScene.m
//  TestGame
//
//  Created by Mitchell Allen on 9/16/09.
//  Copyright 2009 __MyCompanyName__. All rights reserved.
//
// See these links for additional info and credit:
// http://mitchallen.com/iphone/archives/371
// http://mitchallen.com/iphone/archives/304
// http://mitchallen.com/iphone/archives/424
// 

#import "TestScene.h"

#pragma mark -

@implementation TestScene

-(id) init {
	self = [super init];
	if( self != nil ) {
		[self addChild: [TestLayer node] z:1];
	}
	return self;
}

@end

#pragma mark -

static int sceneIdx=-1;

///////////////////////////////////////////////////
// In order for a test layer to appear you must
// add a string for its class name to this array.
// Test layers are defined in MyTests.*

static NSString *transitions[] = {
	@"TestLayer01",
	@"TestLayer02",
	@"TestLayer03",
};

Class nextAction()
{
	// Retrieve the name of the next layer class
	// and return a class based on that string.
	
	sceneIdx++;
	sceneIdx = sceneIdx 
		% ( sizeof(transitions) / sizeof(transitions[0]) );
	NSString *r = transitions[sceneIdx];
	Class c = NSClassFromString(r);
	return c;
}

Class backAction()
{
	// Retrieve the name of the previous layer class
	// and return a class based on that string.
	
	sceneIdx--;
	if( sceneIdx < 0 )
		sceneIdx = sizeof(transitions) / sizeof(transitions[0]) -1;	
	NSString *r = transitions[sceneIdx];
	Class c = NSClassFromString(r);
	return c;
}

Class restartAction()
{
	// Retrieve the name of the current layer class
	// and return a class based on that string.
	
	if( sceneIdx < 0 || sceneIdx >= sizeof(transitions) ) return nil;
	
	NSString *r = transitions[sceneIdx];
	Class c = NSClassFromString(r);
	return c;
}

#pragma mark -

@implementation TestLayer

-(id) init {
	self = [super init];
	if(self != nil) {		
		
		// Initialize and add test images so they can be used 
		// by derived test layers.
		
		// Note that because we 'retain' the images,
		// we will need to release them in dealloc.
		
		grossini = [[Sprite spriteWithFile:@"grossini.png"] retain];
		tamara = 
		  [[Sprite spriteWithFile:@"grossinis_sister1.png"] retain];
		
		[self addChild: grossini z:1];
		[self addChild: tamara z:2];
		
		[self centerSprites];
		
		CGSize s = [[Director sharedDirector] winSize];
		
		// Display the title property for the current layer.
		
		Label* label = [Label 
				labelWithString:[self title] 
				fontName:@"Arial" 
				fontSize:32];
		[self addChild: label];
		[label setPosition: ccp(s.width/2, s.height-50)];
		
		// Create a graphics-based layer navigation menu to be 
		// used by all derived test layers.
		
		MenuItemImage *item1 = [MenuItemImage 
								itemFromNormalImage:@"b1.png" 
								selectedImage:@"b2.png" 
								target:self 
								selector:@selector(backCallback:)];
		MenuItemImage *item2 = [MenuItemImage 
								itemFromNormalImage:@"r1.png" 
								selectedImage:@"r2.png" target:self
								selector:@selector(restartCallback:)];
		MenuItemImage *item3 = [MenuItemImage 
								itemFromNormalImage:@"f1.png" 
								selectedImage:@"f2.png" 
								target:self 
								selector:@selector(nextCallback:)];
		
		Menu *menu = [Menu menuWithItems:item1, item2, item3, nil];
		menu.position = CGPointZero;
		item1.position = ccp(480/2-100,30);
		item2.position = ccp(480/2, 30);
		item3.position = ccp(480/2+100,30);
		[self addChild: menu z:1];
	}
	
	return self;
}

-(void) centerSprites
{
	// Take our two test sprites and center them on the screen.
	
	CGSize s = [[Director sharedDirector] winSize];
	
	[grossini setPosition: ccp(s.width/3, s.height/2)];
	[tamara setPosition: ccp(2*s.width/3, s.height/2)];
}

-(NSString*) title
{
	// Create a default title for the opening layer.
	
	// Test layers should override this call.
	
	return @"Press Arrows to Continue";
}

-(void) dealloc
{
	// Since our test sprites were retained, 
	// we must now release them.
	
	[grossini release]; 
	[tamara release];
	[super dealloc];
}

-(void) setLayer: (Class) classLayer {
	
	// Replace the current layer with one based another class object.
	
	if( classLayer == nil ) return;
	
	Scene *s = [Scene node];
	[s addChild: [classLayer node]];
	[[Director sharedDirector] replaceScene: s];
}

-(void) restartCallback: (id) sender
{	
	// When the user clicks the restart button 
	// (the green circle in the current UI)
	// reload the current layer, 
	// triggering a restart of the action
	
	[self setLayer: restartAction()];
}

-(void) nextCallback: (id) sender
{
	// When the user clicks the next arrow
	// (the green right arrow in the current UI)
	// load the next layer in the list.
	
	[self setLayer: nextAction()];
}

-(void) backCallback: (id) sender
{	
	// When the user clicks the back arrow
	// (the green left arrow in the current UI)
	// load the previous layer in the list.
	
	[self setLayer: backAction()];
}

@end

